"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ListItem_1 = require("./ListItem");
const SerializeError_1 = require("./SerializeError");
const Editor_1 = require("./Editor");
const getDefaultChildResolver = (spec) => (documentId) => {
    let editor = new Editor_1.EditorBuilder().id('editor').documentId(documentId);
    if (spec.schemaType) {
        editor = editor.schemaType(spec.schemaType);
    }
    return editor;
};
class DocumentListItemBuilder extends ListItem_1.ListItemBuilder {
    constructor(spec) {
        super(spec);
        this.spec = spec ? spec : {};
    }
    serialize(options = { path: [] }) {
        const spec = super.serialize(Object.assign({}, options, { titleIsOptional: true }));
        if (!spec.schemaType) {
            throw new SerializeError_1.SerializeError('`schemaType` is required for document list items', options.path, options.index).withHelpUrl(SerializeError_1.HELP_URL.SCHEMA_TYPE_REQUIRED);
        }
        const child = spec.child || getDefaultChildResolver(spec);
        return Object.assign({}, spec, { child, schemaType: spec.schemaType, _id: spec.id });
    }
    clone(withSpec) {
        const builder = new DocumentListItemBuilder();
        builder.spec = Object.assign({}, this.spec, (withSpec || {}));
        return builder;
    }
}
exports.DocumentListItemBuilder = DocumentListItemBuilder;

//# sourceMappingURL=DocumentListItem.js.map
